
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {
}

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when loading or reviving from ghost (optional)
	inst.components.locomotor.walkspeed = 4.5
	inst.components.locomotor.runspeed = 6.5
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)

    if not inst:HasTag("playerghost") then
        onbecamehuman(inst)
    end
end


-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "saitamatwo.tex" )
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "wilson"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(150)
	inst.components.health.fire_damage_scale = 0
	inst.components.health.absorb = -0.20

	inst.components.hunger:SetMax(150)
	inst.components.sanity:SetMax(150)
	
	inst.components.locomotor.walkspeed = 4.5
	inst.components.locomotor.runspeed = 6.5
			
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 1
	inst.components.combat:SetDefaultDamage(50)
	inst.components.combat:SetAreaDamage(5, 1)
	
	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
		
	-- Effect on naked attack
	inst:ListenForEvent("onattackother", function(inst, data)
		if data.target ~= nil and data.weapon == nil then
			local pos = data.target:GetPosition()
			local fx = SpawnPrefab("bigcraterprint")
			local fxx = SpawnPrefab("groundpound_fx")
			local fxxx = SpawnPrefab("groundpoundring_fx")
			fx.Transform:SetPosition(pos.x, pos.y, pos.z)
			fxx.Transform:SetPosition(pos.x, pos.y, pos.z)
			fxxx.Transform:SetPosition(pos.x, pos.y, pos.z)
			for i, v in ipairs(AllPlayers) do
			v:ShakeCamera(CAMERASHAKE.FULL, .7, .02, .3, inst, 40)
		end
		end
	end)
	 
	-- No damage with weapons
	local _od = inst.components.combat.CalcDamage
	inst.components.combat.CalcDamage = function(self, target, weapon, multiplier)
		if weapon ~= nil then
			multiplier = 0
		end
		return _od(self, target, weapon, multiplier)
	end
	
      inst:ListenForEvent("equip", function(inst, data)
        print("I'm wearing something.")
        inst.AnimState:ClearOverrideSymbol("swap_hat")
    end)
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
end

return MakePlayerCharacter("saitamatwo", prefabs, assets, common_postinit, master_postinit, start_inv)